[geos-commits] [SCM] GEOS branch master updated. 9b5cdbfab048e177bb565bf5caf278a773fb36ab

git at osgeo.org git at osgeo.org
Thu Apr 30 08:56:05 PDT 2020


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GEOS".

The branch, master has been updated
       via  9b5cdbfab048e177bb565bf5caf278a773fb36ab (commit)
      from  ebae359519ddb33ff9e7ccfc40d36a412a83ac56 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 9b5cdbfab048e177bb565bf5caf278a773fb36ab
Author: Paul Ramsey <pramsey at cleverelephant.ca>
Date:   Thu Apr 30 08:55:39 2020 -0700

    Match up parameters names to doc names

diff --git a/src/algorithm/construct/LargestEmptyCircle.cpp b/src/algorithm/construct/LargestEmptyCircle.cpp
index 6506442..82ebfbe 100644
--- a/src/algorithm/construct/LargestEmptyCircle.cpp
+++ b/src/algorithm/construct/LargestEmptyCircle.cpp
@@ -64,17 +64,17 @@ LargestEmptyCircle::LargestEmptyCircle(const Geometry* p_obstacles, double p_tol
 
 /* public static */
 std::unique_ptr<Point>
-LargestEmptyCircle::getCenter(const Geometry* polygonal, double tolerance)
+LargestEmptyCircle::getCenter(const Geometry* p_obstacles, double p_tolerance)
 {
-    LargestEmptyCircle lec(polygonal, tolerance);
+    LargestEmptyCircle lec(p_obstacles, p_tolerance);
     return lec.getCenter();
 }
 
 /* public static */
 std::unique_ptr<LineString>
-LargestEmptyCircle::getRadiusLine(const Geometry* polygonal, double tolerance)
+LargestEmptyCircle::getRadiusLine(const Geometry* p_obstacles, double p_tolerance)
 {
-    LargestEmptyCircle lec(polygonal, tolerance);
+    LargestEmptyCircle lec(p_obstacles, p_tolerance);
     return lec.getRadiusLine();
 }
 

-----------------------------------------------------------------------

Summary of changes:
 .../geos/algorithm/construct/LargestEmptyCircle.h    | 20 ++++++++++----------
 src/algorithm/construct/LargestEmptyCircle.cpp       |  8 ++++----
 2 files changed, 14 insertions(+), 14 deletions(-)


hooks/post-receive
diff --git a/include/geos/algorithm/construct/LargestEmptyCircle.h b/include/geos/algorithm/construct/LargestEmptyCircle.h
index fb8c8de..6bd9d2c 100644
--- a/include/geos/algorithm/construct/LargestEmptyCircle.h
+++ b/include/geos/algorithm/construct/LargestEmptyCircle.h
@@ -64,31 +64,31 @@ public:
     /**
     * Creates a new instance of a Largest Empty Circle construction.
     *
     * @param obstacles a geometry representing the obstacles (points and lines)
     * @param tolerance the distance tolerance for computing the circle center point
     */
-    LargestEmptyCircle(const geom::Geometry* polygonal, double tolerance);
+    LargestEmptyCircle(const geom::Geometry* p_obstacles, double p_tolerance);
     ~LargestEmptyCircle() = default;
 
     /**
     * Computes the center point of the Largest Empty Circle
     * `within a set of obstacles, up to a given tolerance distance.
     *
     * @param obstacles a geometry representing the obstacles (points and lines)
     * @param tolerance the distance tolerance for computing the center point
     * @return the center point of the Largest Empty Circle
     */
-    static std::unique_ptr<geom::Point> getCenter(const geom::Geometry* polygonal, double tolerance);
+    static std::unique_ptr<geom::Point> getCenter(const geom::Geometry* p_obstacles, double p_tolerance);
 
     /**
     * Computes a radius line of the Largest Empty Circle
     * within a set of obstacles, up to a given distance tolerance.
     *
     * @param obstacles a geometry representing the obstacles (points and lines)
     * @param tolerance the distance tolerance for computing the center point
     * @return a line from the center of the circle to a point on the edge
     */
-    static std::unique_ptr<geom::LineString> getRadiusLine(const geom::Geometry* polygonal, double tolerance);
+    static std::unique_ptr<geom::LineString> getRadiusLine(const geom::Geometry* p_obstacles, double p_tolerance);
 
     std::unique_ptr<geom::Point> getCenter();
     std::unique_ptr<geom::Point> getRadiusPoint();
@@ -119,7 +119,7 @@ private:
     * Their containing cells will be last in the priority queue
     * (but will still end up being tested since they may be refined).
     *
-    * @param p the point to compute the distance for
+    * @param c the point to compute the distance for
     * @return the signed distance to the constraints (negative indicates outside the boundary)
     */
     double distanceToConstraints(const geom::Coordinate& c);
@@ -64,31 +64,31 @@ public:
     * Creates a new instance of a Largest Empty Circle construction.
     *
-    * @param obstacles a geometry representing the obstacles (points and lines)
-    * @param tolerance the distance tolerance for computing the circle center point
+    * @param p_obstacles a geometry representing the obstacles (points and lines)
+    * @param p_tolerance the distance tolerance for computing the circle center point
     */
@@ -64,31 +64,31 @@ public:
     * `within a set of obstacles, up to a given tolerance distance.
     *
-    * @param obstacles a geometry representing the obstacles (points and lines)
-    * @param tolerance the distance tolerance for computing the center point
+    * @param p_obstacles a geometry representing the obstacles (points and lines)
+    * @param p_tolerance the distance tolerance for computing the center point
     * @return the center point of the Largest Empty Circle
     */
@@ -64,31 +64,31 @@ public:
     * within a set of obstacles, up to a given distance tolerance.
     *
-    * @param obstacles a geometry representing the obstacles (points and lines)
-    * @param tolerance the distance tolerance for computing the center point
+    * @param p_obstacles a geometry representing the obstacles (points and lines)
+    * @param p_tolerance the distance tolerance for computing the center point
     * @return a line from the center of the circle to a point on the edge
     */
-- 
GEOS


More information about the geos-commits mailing list